<?php
	/*
	MGB 0.6.x - OpenSource PHP and MySql Guestbook
	Copyright (C) 2004 - 2011 Juergen Grueneisl - http://www.m-gb.org/

	This program is free software; you can redistribute it and/or modify
	it under the terms of the GNU General Public License as published by
	he Free Software Foundation; either version 2 of the License, or
	(at your option) any later version.

	This program is distributed in the hope that it will be useful,
	but WITHOUT ANY WARRANTY; without even the implied warranty of
	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
	GNU General Public License for more details.

	You should have received a copy of the GNU General Public License
	along with this program; if not, write to the Free Software
	Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
	*/

	// ====================== //
	// lang_admin.php - Dutch //
	// ====================== //
	//
	// This languagefile was translated by Gerard Vandeninden gerard@brookstruefriends.nl

	// general values
	$lang['no'] = "nee";
	$lang['yes'] = "ja";
	$lang['save'] = "Opslaan";
	$lang['asc'] = "Aflopend";
	$lang['desc'] = "Oplopend";
	$lang['administrator'] = "administrator";
	$lang['moderator'] = "moderator";
	$lang['gravatar_type_0'] = "Standard";
	$lang['gravatar_type_1'] = "Mistery-Man";
	$lang['gravatar_type_2'] = "Identicon";
	$lang['gravatar_type_3'] = "Monsterid";
	$lang['gravatar_type_4'] = "Wavatar";
	$lang['gravatar_type_5'] = "Retro";
	$lang['gravatar_position_left'] = "Links van het bericht";
	$lang['gravatar_position_right'] = "Rechts van het bericht";
	$lang['timestamp'] = "Tijdstempel";
	$lang['quote'] = "Citeren uit";

	// login.php
	$lang['title'] = "MGB {MGB_VERSION} - Administratie";
	$lang['login_username'] = "Usernaam:";
	$lang['login_password'] = "wachtwoord:";
	$lang['login_lostpassword'] = "wachtwoord vergeten";
	$lang['login'] = "Log in";
	$lang['logout'] = "Log uit";
	$lang['login_ok'] = "Welkom <b>{SESSION_USERNAME}</b>.";
	$lang['logged_in'] = "Je bent ingelogd als <b>{SESSION_USERNAME}</b>";
	$lang['logged_out'] = "Vul gerbruikernaam en wachtwoord in.";
	$lang['please_wait'] = "Je bent succesvol ingelogd.<br>Een  moment a.u.b....";

	// errormessages
	$lang['errormessage1'] = "Vul alle velden in!";
	$lang['errormessage2'] = "Deze usernaam/wachtwoord combinatie bestaat niet.";
	$lang['errormessage3'] = "Uw account is door de administrator gedeactiveerd.";
	$lang['errormessage4'] = "U hebt geen toegang tot deze site.";
	$lang['errormessage5'] = "Het opgegeven wachtwoord is fout.";
	$lang['errormessage6'] = "De nieuwe wachtwoorden zijn niet gelijk.";
	$lang['errormessage7'] = "Het opgegeven e-mail adres is niet geldig of niet ingevuld.";
	$lang['errormessage8'] = "Je kan je eigen administrator rechten niet verwijderen, disable je account of verwijder het.";
	$lang['errormessage9'] = "Je was te lang inactief en bent automatisch uitgelogd.";
	$lang['errormessage10'] = "Bij je laatste bezoek heb je niet correct uitgelogd. Het systeem heeft dit voor jou gedaan.<br><br>Gebruik voor de veiligheid altijd de ''Logout'' knop om uit te loggen. Dank u.";
	$lang['errormessage11'] = "De gebruikernaam of dit e-mailadres zijn al in gebruik.";
	$lang['errormessage12'] = "Het wachtwoord is niet correct of verlopen.";
	$lang['errormessage13'] = "Er is al een nieuw wachtwoord aangevraagd voor dit account.<br>Het is niet mogelijk een nieuw wachtwoord aan te vragen totdat het vorige is bevestigd of verlopen.";
	$lang['errormessage14'] = "De e-mail kon niet verzonden worden. Er is misschien een probleem met de mailserver.";
	$lang['errormessage15'] = "Versienummer kan niet achterhaald worden omdat <a href=\"http://php.net/manual/en/function.fopen.php\">fopen()</a> is gedeactiveerd op je server.<br>Neem contact op met je host om dit probleem op te lossen.<br><br>Kijk voor de nieuwste versie op http://www.m-gb.org/.";
	$lang['errormessage16'] = "Je nieuwe wachtwoord is te kort. veilige wachtwoorden zijn minstens ".$settings['password_min_length']." karakters lang.";

	// general strings
	$lang['back_to_mainpage'] = "Terug naar de hoofdpagina";
	$lang['back'] = "Terug";
	$lang['go'] = "Go!";
	$lang['entry'] = "Bericht";
	$lang['entries'] = "Berichten";
	$lang['no_entries'] = "Geen berichten beschikbaar.";
	$lang['no_deactivated_entries'] = "Geen gedeactiveerde berichten beschikbaar.";
	$lang['no_activated_entries'] = "Geen geactiveerde berichten beschikbaar";
	$lang['no_spam_entries'] = "No spam entries available.";
	$lang['entries_on_pages'] = "berichten op {PAGES} pages";
	$lang['page_first'] = "eerste pagina";
	$lang['page_first_symbol'] = "&laquo;";
	$lang['page_forwards'] = "1 pagina vooruit";
	$lang['page_forwards_symbol'] = "&rsaquo;";
	$lang['page_last'] = "Laatste pagina";
	$lang['page_last_symbol'] = "&raquo;";
	$lang['page_backwards'] = "1 pagina terug";
	$lang['page_backwards_symbol'] = "&lsaquo;";
	$lang['captcha_method_code'] = "Securitycode";
	$lang['captcha_method_math'] = "Mathematic";
	$lang['activate_entry'] = "Activeer dit bericht";
	$lang['deactivate_entry'] = "Deactiveer dit bericht";
	$lang['delete_entry'] = "Verwijder dit bericht";
	$lang['mark_as_spam'] = "Markeren als spam";
	$lang['nospam_entry'] = "Markeren als 'geen spam' en activeren";
	$lang['nospam_deactivate_entry'] = "Markeren als 'geen spam' MAAR niet activeren";
	$lang['active'] = "Dit bericht is geactiveerd in het gastenboek";
	$lang['inactive'] = "Dit bericht niet is geactiveerd in het gastenboek";
	$lang['edit_entry'] = "Bewerk dit bericht";
	$lang['do_nothing'] = "Doe niets ...";
	$lang['delete_whole_spam'] = "Delete alle spam entries";
	$lang['mark_all_no_spam_deactivate'] = "Markeer alle entries als 'geen spam' en activeer deze";
	$lang['mark_all_no_spam_activate'] = "Markeer alle entries als 'geen spam' MAAR niet activeren";
	$lang['mark_all_as_spam'] = "Markeer alle entries als spam";
	$lang['activate_all_entries'] = "Activeer alle entries";
	$lang['deactivate_all_entries'] = "Deactiveer alle entries";
	$lang['delete_all_entries'] = "Delete alle entries";

	$lang['sendmail_user_notification_title'] = "Je bericht op {DOMAIN} is geactiveerd";
	$lang['sendmail_user_comment_title'] = "Aan je bericht op {DOMAIN} is een commentaar toegevoegd";
	$lang['sendmail_adduser_title'] = "Je gebruiker gegevens op {DOMAIN}";
	$lang['sendmail_adduser_text'] = "Je bent geregistreerd op {DOMAIN} door een administrator. Hier zijn je gegevens:<br /><br />Gebruikernaam: {ADDUSER_NAME}<br />Wachtwoord: {ADDUSER_PASSWORD}<br /><br />Je kan hier inloggen: {ADDUSER_URL}";
	$lang['sendmail_admin_text'] = "{NAME} heeft een nieuw bericht in het gastenboek aangemaakt.<br /><br />Datum: {DATE}<br />Tijd: {TIME}<br /><br />---<br />{MESSAGE}<br />---<br /><br />{URL_TO_GB}";
	$lang['sendmail_user_text'] = "Hallo {NAME},<br /><br />Bedankt voor je bericht in ons gastenboek. Na beoordeling zal ik dit z.s.m. activeren.";
	$lang['sendmail_user_notification_text'] = "Hallo {NAME},<br /><br />Je bericht op {DOMAIN} is nu geactiveerd. Je kan het hier bekijken: {URL_TO_GB}";
	$lang['sendmail_comment_text'] = "Hallo {NAME},<br /><br />Aan jou bericht<br /><br />---<br />{MESSAGE}<br />---<br /><br />is net een commentaar toegevoegd. Je kan het hier bekijken: {URL_TO_GB}";
	$lang['sendmail_contactmail_text'] = "Je hebt een e-mail van {NAME} over het gastenboek van {DOMAIN}. Hier volgt het bericht:<br /><br />---<br />{MESSAGE}<br />---<br /><br />Datum: {DATE}<br />Tijd: {TIME}";
	$lang['sendmail_new_password_title'] = "Nieuw wachtwoord: Authenticatie";
	$lang['sendmail_new_password_text'] = "Hallo {NAME},<br /><br />Voor jou account is een nieuw wachtwoord gecreeerd. Om dit te valideren klik op de link hieronder binnen de volgende 24h. totdat het nieuwe is geactiveerd blijft het oude geldig.<br /><br />Als de link niet binnen 24h geklikt wordt verloopt het nieuwe wachtwoord.<br /><br />{NEW_PASSWORD_LINK}";
	$lang['sendmail_new_password_created_title'] = "Het nieuwe wachtwoord is geactiveerd.";
	$lang['sendmail_new_password_created_text'] = "Hallo {NAME},<br /><br />je nieuwe wachtwoord is geactiveerd. Hierbij je	vernieuwde gebruiker gegevens.<br /><br />Usernaam: {NAME}<br />Wachtwoord: {NEW_PASSWORD}";

	// navigation
	$lang['settings'] = "Instellingen";
	$lang['activate'] = "Berichten activeren";
	$lang['deactivate'] = "Berichten deactiveren";
	$lang['delete'] = "Berichten verwijderen";
	$lang['edit'] = "Berichten bewerken";
	$lang['spam'] = "Spam entries";
	$lang['edit_smilies'] = "Bewerk smilies";
	$lang['users'] = "Gebruiker administratie";
	$lang['stats'] = "Statistieken";
	$lang['license'] = "Licentie";
	$lang['forum'] = "Forum";
	$lang['bugreport'] = "Bug rappoteren";
	$lang['version'] = "Versie";
	$lang['manual'] = "Documentatie";
	$lang['to_guestbook'] = "Naar het gastenboek";
	$lang['paypal'] = "Als je MGB goed vindt, kan je een donatie aan het project geven om verdere ontwikkelingen te steunen.";

	// settings.inc.php
	$lang['edit_caption_general'] = "Algemene instellingen";
	$lang['edit_caption_look'] = "Look &amp; feel";
	$lang['edit_caption_bbcodes'] = "BBCodes";
	$lang['edit_caption_smilies'] = "Emoticons";
	$lang['edit_caption_gravatars'] = "Gravatar-support";
	$lang['edit_caption_security'] = "Security";
	$lang['edit_caption_email'] = "e-mail";
	$lang['edit_save_message'] = "Instellingen succesvol opgeslagen.";
	$lang['edit_title'] = "Titel:";
	$lang['edit_h_author'] = "Auteur:";
	$lang['edit_h_domain'] = "Domein:";
	$lang['edit_gb_path'] = "Pad naar het gastenboek:";
	$lang['edit_h_keywords'] = "Keywords:";
	$lang['edit_h_description'] = "Beschrijving:";
	$lang['edit_admin_name'] = "Naam van administrator:";
	$lang['edit_admin_email'] = "E-mail adres van administrator:";
	$lang['edit_admin_gbemail'] = "E-mail adres van gastenboek:";
	$lang['edit_sendmail_admin'] = "E-mail bericht versturen:";
	$lang['edit_sendmail_admin_text'] = "Tekst voor bericht:";
	$lang['edit_sendmail_user'] = "Bedankt mail naar de gebruiker:";
	$lang['edit_sendmail_user_text'] = "Tekst voor bedankje:";
	$lang['edit_sendmail_user_notification_text'] = "Tekst voor activatiemail:";
	$lang['edit_sendmail_comment_text'] = "Tekst voor commentaar mail:";
	$lang['edit_sendmail_contactmail_text'] = "Tekst voor e-mail over het gastenboek:";
	$lang['edit_template_path'] = "Template:";
	$lang['edit_template_style_path'] = "Template-Style:";
	$lang['edit_iconset_path'] = "Iconset:";
	$lang['edit_language_path'] = "Taal:";
	$lang['edit_badwords'] = "Badwords:";
	$lang['edit_bbcode'] = "BBcodes:";
	$lang['edit_allow_img_tag'] = "IMG-Tag toestaan:";
	$lang['edit_max_img_width'] = "Maximum Breedte van afbeelding:";
	$lang['edit_max_img_height'] = "Maximum Hoogte van afbeelding:";
	$lang['edit_center_img'] = "Centreer afbeeldingen:";
	$lang['edit_allow_flash_tag'] = "FLASH-Tag toestaan:";
	$lang['edit_max_flash_width'] = "Maximum Breedte van Flash:";
	$lang['edit_max_flash_height'] = "Maximum Hoogte van Flash:";
	$lang['edit_center_flash'] = "Centreer Flash:";
	$lang['edit_smileys'] = "Smileys:";
	$lang['edit_smileys_break'] = "Aantal smilies per regel:";
	$lang['edit_smileys_order'] = "Volgorde van smilies:";
	$lang['edit_captcha'] = "Captcha:";
	$lang['edit_captcha_method'] = "Soort captcha:";
	$lang['edit_captcha_coords'] = "Captcha co&ouml;rdinaten:";
	$lang['edit_captcha_color'] = "Captcha tekstkleur:";
	$lang['edit_captcha_angle'] = "Captcha hoek:";
	$lang['edit_akismet_plugin'] = "Akismet-Plugin:";
	$lang['edit_akismet_api'] = "Akismet API Key:";
	$lang['edit_akismet_mark_as_spam'] = "Spam markering:";
	$lang['edit_time_lock'] = "Wachttijd tot volgende bericht:";
	$lang['edit_time_lock_value'] = "Minimum Wachttijd:";
	$lang['edit_time_lock_maxtime'] = "Maximum Wachttijd:";
	$lang['edit_user_notification'] = "Gebruiker bericht:";
	$lang['edit_user_show_email'] = "Gebruiker mail in het gastenboek:";
	$lang['edit_session_timeout'] = "Sessie timeout:";
	$lang['edit_password_min_length'] = "Minimum lengte voor wachtwoorden:";
	$lang['edit_moderated'] = "Gecontroleerd Gastenboek:";
	$lang['edit_entries_per_page'] = "Berichten per pagina:";
	$lang['edit_entries_order'] = "Volgorde van de berichten:";
	$lang['edit_entries_order_asc_desc'] = "Sorteervolgorde:";
	$lang['edit_entries_numbering'] = "Nummervolgorde:";
	$lang['edit_spam_protection'] = "E-mail spam beveiliging:";
	$lang['edit_ipblocker'] = "IP-Blocker:";
	$lang['edit_wordwrap'] = "Wordwrap:";
	$lang['edit_dateform'] = "Datum formaat:";
	$lang['edit_gravatar_show'] = "activeer gravatars:";
	$lang['edit_gravatar_rating'] = "Gravatar rating:";
	$lang['edit_gravatar_type'] = "Niet geregistreerde gravatars:";
	$lang['edit_gravatar_size'] = "Gravatar grootte:";
	$lang['edit_gravatar_position'] = "Plaats:";

	$lang['edit_expl_title'] = "Titel van het gastenboek.";
	$lang['edit_expl_h_author'] = "Naam van de auteur van de webpagina.";
	$lang['edit_expl_h_domain'] = "Top Level Domein (TLD) waar het gastenboek is geinstalleerd <b>zonder http://</b> aan het begin en <b>/</b> op het eind. (www.voorbeeld.net)";
	$lang['edit_expl_gb_path'] = "Het pad relatief aan hetTLD waar het gastenboek is geinstalleerd.";
	$lang['edit_expl_h_keywords'] = "Keywords gescheiden door komma`s.";
	$lang['edit_expl_h_description'] = "Een korte beschrijving van de pagina.";
	$lang['edit_expl_admin_name'] = "De administratornaam of gewoon ''admin''.";
	$lang['edit_expl_admin_email'] = "Naar dit adres worden berichten over nieuwe gastenboek berichten gestuurd.";
	$lang['edit_expl_admin_gbemail'] = "Wordt gebruikt als afzender adres.";
	$lang['edit_expl_sendmail_admin'] = "Indien deze optie is geactiveerd, krijgt de admin e-mails wanneer er nieuwe berichten zijn.";
	$lang['edit_expl_sendmail_admin_text'] = "Deze tekst wordt naar de admin gestuurd bij nieuwe berichten.<br><br>Beschikbare placeholder: {NAME}, {DATE}, {TIME}, {MESSAGE}, {DOMAIN}, {URL_TO_GB}";
	$lang['edit_expl_sendmail_user'] = "Indien deze optie is geactiveerd, krijgt de gebruiker een bedank-bericht.";
	$lang['edit_expl_sendmail_user_text'] = "Deze tekst wordt naar de gebruiker gestuurd indien bedank-bericht is geactiveerd.<br><br>Beschikbare placeholder: {NAME}, {DATE}, {TIME}, {MESSAGE}, {DOMAIN}, {URL_TO_GB}";
	$lang['edit_expl_sendmail_user_notification_text'] = "Deze tekst wordt naar de gebruiker gestuurd zodra zijn bericht is geactiveerd. Dit moet hij wel accepteren wanneer hij zijn bericht plaatst.<br><br>Beschikbare placeholder: {NAME}, {DATE}, {TIME}, {MESSAGE}, {DOMAIN}, {URL_TO_GB}";
	$lang['edit_expl_sendmail_comment_text'] = "Deze tekst wordt naar de gebruiker gestuurd, wanneer een admin een commentaar aan zijn bericht toevoegd. Dit moet hij wel accepteren wanneer hij zijn bericht plaatst.<br><br>Beschikbare placeholder: {NAME}, {DATE}, {TIME}, {MESSAGE}, {DOMAIN}, {URL_TO_GB}";
	$lang['edit_expl_sendmail_contactmail_text'] = "Deze tekst wordt naar de gebruikers gestuurd, als zij een e-mail krijgen over spam beveiliging.<br><br>Beschikbare placeholder: {NAME}, {DATE}, {TIME}, {MESSAGE}, {DOMAIN}, {URL_TO_GB}";
	$lang['edit_expl_template_path'] = "De template die gebruikt gaat worden.";
	$lang['edit_expl_template_style_path'] = "De gewenste stijl van de template. Je kan dit niet selecteren totdat deze geladen is.";
	$lang['edit_expl_iconset_path'] = "De gewenste grafic-set die de icons levert, smileys en captcha-achtergronden onafhankelijk van de template.";
	$lang['edit_expl_language_path'] = "De taal die gebruikt wordt.<br><br><b>ATTENTIE:</b> Sinds versie <b>0.6.5</b> zijn talen die caracterset latin9 (iso-8859-15) gebruiken <b>NIET LANGER</b> ondersteund. Als je problemen hebt met missende variabelen, lege tekstvelden, enz, probeer over te schakelen naar een utf-8 taal en verwijder alle ''latin9''-talen uit de map ''language''.<br><br>Als je dan nog problemen hebt met umlauts of speciale caracters voer dan ''convert_ansi.php'' in de map 'install' uit.";
	$lang['edit_expl_language_charset'] = "Tekenset:";
	$lang['edit_expl_badwords'] = "Vul hier ongewenste woorden in gescheiden door comma`s, deze worden vervangen door sterren (*). Laat leeg om te deactiveren.";
	$lang['edit_expl_bbcode'] = "Laat de gebruiker toe om tekst te bewerken.";
	$lang['edit_expl_allow_img_tag'] = "De implementatie van afbeeldingen in een gastenboek bericht komt met enkele security risks. Beelden kunnen malware bevatten, of een beeld mag juridisch gezien niet gepubliceerd worden. Heel veel en grote afbeeldingen kunnen het laden van het gastenboek vertragen.<br><br><b>De IMG-Tag zou enkel in een gemodereerd gastenboek mogen geactiveerd worden.</b>";
	$lang['edit_expl_max_img_width'] = "Definieerd de maximum breedte van een afbeelding.<br><br><b>ATTENTIE: Dit werkt enkel als <a href='http://de2.php.net/manual/en/function.getimagesize.php' target='_blank' title='php.net'>getimagesize();</a> werkt, of als de hoogte en breedte in de [img]-Tag zijn aangegeven zoals hier -> [img=width,height]address of image[/img]).</b>";
	$lang['edit_expl_max_img_height'] = "Definieerd de maximum hoogte van een afbeelding.<br><br><b>ATTENTIE: Dit werkt enkel als <a href='http://de2.php.net/manual/en/function.getimagesize.php' target='_blank' title='php.net'>getimagesize();</a> werkt, of als de hoogte en breedte in de [img]-Tag zijn aangegeven zoals hier -> [img=width,height]address of image[/img]).</b>";
	$lang['edit_expl_center_img'] = "Definieerd of [img]-Tag afbeeldingen gecentreerd worden weergegeven.";
	$lang['edit_expl_allow_flash_tag'] = "Laat het invoegen van flash video toe, zoals van youtube.<br><br><b>Voor de veiligheid moet je dit enkel activeren als je een gecontroleerd gastenboek hebt.</b>";
	$lang['edit_expl_max_flash_width'] = "Maximum breedte van een flashvideo.";
	$lang['edit_expl_max_flash_height'] = "Maximum hoogte van een flashvideo.";
	$lang['edit_expl_center_flash'] = "Plaatst een flashvideo in het midden.";
	$lang['edit_expl_smileys'] = "Laat de gebruiker toe om smileys te gebruiken.";
	$lang['edit_expl_smileys_break'] = "Maximaal aantal smilies per regel in ''newentry.php''. Kan nuttig zijn indien er veel smilies gebruikt worden.";
	$lang['edit_expl_smileys_order'] = "Geeft aan hoe smilies gesorteerd zijn. Oplopend of Aflopend.";
	$lang['edit_expl_captcha'] = "Indien geactiveerd moet er een catcha-code ingevuld worden om een bericht toe te voegen of een e-mail te verzenden.";
	$lang['edit_expl_captcha_method'] = "Je kan kiezen tussen een veiligheidscode, of een rekensom die de gebruiker moet oplossen.";
	$lang['edit_expl_captcha_coords'] = "Definieert de plaats waar de tekst begint in de achtergrond. Het begin is de <b>Linker onderkant van het eerste caracter</b>.";
	$lang['edit_expl_captcha_color'] = "Definieert de tekstkleur van de captcha. De waarde moet in HTML-formaat zijn zonder de '#'.<br><br><b>Juist: <span class='newer_version'>505050</span><br>Fout: <span class='old_version'>#505050</span></b>";
	$lang['edit_expl_captcha_angle'] = "Deze twee waarden definieren willekeurig de hoek waarmee de captcha wordt getekend.<br><br>The left value has to be <b>lower</b> than the right value.";
	$lang['edit_expl_akismet_plugin'] = "Akismet is een externe anti-spam-service, die nieuwe berichten controleert op spam. de akismet-plugin kan hier gedownload worden <a href='http://www.m-gb.org/index.php?id=download_gb' title='Download Akismet Plugin'>http://www.m-gb.org/</a>.<br><br><b>ATTENTIE: Met het gebruik van de 'akismet'-plugin accepteer je het verzenden van data naar een server in de USA. Indien je hier niet mee accoord bent MAG JE 'Akismet' NIET GEBRUIKEN. Ook de Users moeten hiermee accoord gaan als je deze plugin activeerd.</b>";
	$lang['edit_expl_akismet_api'] = "Om Akismet te kunnen gebruiken heb je een <a href='http://akismet.com/signup/#free' title='Akismet API Key'>API Key</a> nodig. Meld je aan voor een gratis account en vul je key hier in.";
	$lang['edit_expl_akismet_check_ok'] = "<span class='same_version' style='font-size: 14px;'>Akismet is geistalleerd!</span>";
	$lang['edit_expl_akismet_check_fail'] = "<span class='old_version' style='font-size: 14px;'>Akismet is NIET geistalleerd!</span>";
	$lang['edit_expl_akismet_mark_as_spam'] = "Indien deze optie is geactiveerd, worden positieve Akismet entries gemarkeerd als spam en verschijnen in het administratie panel hier kan je ze zelf controleren en bekijken wat je ermee doet.";
	$lang['edit_expl_time_lock'] = "Indien deze optie is geselecteerd wordt er op de achtergrond en teller gestart die voorkomt dat het nieuwe bericht te snel wordt verstuurd. Indien de gebruiker te snel is met zijn bericht verschijnt er een bericht met de tijd die hij nog moet wachten totdat hij zijn bericht kan verzenden.";
	$lang['edit_expl_time_lock_value'] = "Minimum wachttijdtijd tot het verzenden van het bericht.";
	$lang['edit_expl_time_lock_maxtime'] = "Maximum tijd om een bericht aan te maken. Als het te lang duurt herstart de teller.";
	$lang['edit_expl_user_notification'] = "Laat de gebruiker toe om te beslissen of hij een e-mail wil ontvangen wanneer zijn bericht wordt geactiveerd.";
	$lang['edit_expl_user_show_email'] = "Laat de gebruiker toe om te beslissen of zijn e-mail adres getoond wordt in het gastenboek of niet. Indien hij de keuze uitschakeld kan alleen de admin hem een e-mail sturen.";
	$lang['edit_expl_session_timeout'] = "Een inactieve gebruiker wordt automatisch uitgelogd indien de tijd is verstreken. Uitgedrukt in <b>seconden</b>. Waarde moet >= <b>60</b>.";
	$lang['edit_expl_password_min_length'] = "Definieert de minimum lengte van wachtwoorden van Administrators / Moderators.";
	$lang['edit_expl_moderated'] = "Indien geactiveerd moeten posts eerst geactiveerd worden door de admin.";
	$lang['edit_expl_entries_per_page'] = "Aantal posts per pagina. De waarde <b>mag niet 0 zijn</b>.";
	$lang['edit_expl_entries_order'] = "Defineerd de volgorde waarin posts genummerd worden";
	$lang['edit_expl_entries_order_asc_desc'] = "Sorteervolgorde van berichten.";
	$lang['edit_expl_entries_numbering'] = "Nummering van berichten.<br><br><b>Attentie:</b> Dit heeft niets te maken met de sorteervolgorde.";
	$lang['edit_expl_spam_protection'] = "Wanneer geactiveerd krijgt de gebruiker een contact-form, als hij op het eMail-symbool in een  post klikt. Op deze manier zullen e-mail adressen <b>niet</b> getoond worden.";
	$lang['edit_expl_ipblocker'] = "Voorkomt meerder posts van 1 gebruiker in rij.";
	$lang['edit_expl_wordwrap'] = "Geeft het aantal caracters aan voordat een heel lang woord wordt afgebroken. <b>0</b> om te deactiveren.";
	$lang['edit_expl_dateform'] = "De manier waarop de datum getoond wordt. Aanpassen is mogelijk met de PHP-functie <a class='admin' href='http://www.php.net/manual/en/function.date.php' title='date()' target='_blank'>date()</a>.";
	$lang['edit_expl_gravatar_show'] = "Gravatars (Global Recognized Avatars) zijn kleine afbeeldingen die naast de post van de gebruiker getoond worden. Zij hangen af van, als de gebruiker een <a class=\"admin\" href=\"http://site.gravatar.com/\" target=\"_blank\" title=\"Gravatar Service\">registred</a> is zijn e-mail adres bij deze service.";
	$lang['edit_expl_gravatar_rating'] = "Definieerd tot welke rating gravatars getoond worden.<br><br><b>G</b> = voor elke leeftijd<br><b>PG</b> = light violence illustration, provocative dressed people and gestures<br><b>R</b> = intensive violence illustration, obscenity<br><b>X</b> = explicit sexual pictures";
	$lang['edit_expl_gravatar_type'] = "Hier geef je aan hoe een gravatar wordt weergegeven indien het email adres van de gebruikers niet geregistreerd is bij de service.";
	$lang['edit_expl_gravatar_size'] = "Grootte van de gravatar in <b>pixels</b>.";
	$lang['edit_expl_gravatar_position'] = "Plaatst de gravatar links of rechts van het bericht.";

	// edit.php
	$lang['ID'] = "ID:";
	$lang['ip'] = "IP:";
	$lang['date'] = "Datum:";
	$lang['time'] = "Tijd:";
	$lang['name'] = "Naam:";
	$lang['city'] = "Plaats:";
	$lang['email'] = "E-mail:";
	$lang['icq'] = "ICQ:";
	$lang['aim'] = "AIM:";
	$lang['msn'] = "MSN:";
	$lang['hp'] = "Homepage:";
	$lang['message'] = "Bericht:";
	$lang['user_notification'] = "Bericht voor activatie of commentaar:";
	$lang['user_show_email'] = "Laat e-mail adres in het gastenboek zien:";
	$lang['comment'] = "Commentaar:";

	// smilies.inc.php
	$lang['add_smilies_descr'] = "Hier kan je smilies bewerken of verwijderen.<br><br>Alle smilies moeten in de map <b>'images/smilies/'</b> staan in de root directory van het gastenboek. Vul de naam van het bestand in de <b>lege tekstbox onder bestandsnaam</b>, de vervangende tekst en de afmetingen, en druk op <b>Opslaan</b>.<br><br>Je kan meer dan 1 vervangende tekst opgeven per smilie. Gescheiden door een <b>comma en een spatie</b>. De <b>eerste</b> caractercombinatie zal gebruikt worden om de smilie in de tekst in te voegen in ''newentry.php''.<br><br><span class='same_version'>Juist:</span> :smile:, :), :-)<br><span class='old_version'>Fout:</span> :smile:,:),:-)<br><br><b>Let op: Indien je bestaande smilies veranderd, die al gebruikt zijn in berichten, kunnen deze niet correct meer worden weergegeven! Je zal deze berichten handmatig moeten aanpassen.</b>";
	$lang['smiley_path'] = "Bestandsnaam";
	$lang['smiley_replacement'] = "Vervangende tekst";
	$lang['add_new_smiley'] = "Smiley toevoegen";
	$lang['delete_checked_smilies'] = "... verwijder uit lijst, behoud niet aangevinkt";
	$lang['keep_checked_smilies'] = "... behoud, verwijder niet aangevinkt";
	$lang['smiley_width'] = "Breedte";
	$lang['smiley_height'] = "Hoogte";
	$lang['smilies'] = "Smilies";
	$lang['checked_smilies'] = "Aangevinkte smilies ...";

	// edit_user.inc.php
	$lang['user_is_active'] = "Gebruiker is actief:";
	$lang['r_user_type'] = "Gebruiker is:";
	$lang['r_settings'] = "Verander settings:";
	$lang['r_activate'] = "Berichten activeren:";
	$lang['r_deactivate'] = "Berichten deactiveren:";
	$lang['r_delete'] = "Berichten verwijderen:";
	$lang['r_edit'] = "Berichten aanpassen:";
	$lang['r_spam'] = "Manage spam:";
	$lang['r_edit_smilies'] = "Bewerk smilies";
	$lang['old_password'] = "Uw huidige wachtwoord:";
	$lang['new_password_1'] = "Nieuw wachtwoord:";
	$lang['new_password_2'] = "Bevestig nieuw wachtwoord:";
	$lang['delete_user'] = "Bevestig:";
	$lang['edit_user_caption_rights'] = "Rechten (alleen voor moderators)";
	$lang['edit_user_caption_password'] = "Wachtwoord voor deze gebruiker:";
	$lang['edit_user_caption_delete_user'] = "Verwijder deze gebruiker:";
	$lang['edit_user_caption_old_password'] = "Uw huidige wachtwoord:";
	$lang['user_add'] = "Gebruiker toevoegen";
	$lang['user_edit'] = "Gebruiker aanpassen";
	$lang['edit_user_caption_send_account_data'] = "Stuur gebruiker	gegevens";
	$lang['send_account_data'] = "Stuur per e-mail?";

	// version.inc.php
	$lang['current_version'] = "geinstallerde versie:";
	$lang['stable_version'] = "nieuwste stabiele versie:";
	$lang['unstable_version'] = "nieuwste instabiele versie:";
	$lang['old_version'] = "Uw versie is te oud.<br>Een update wordt aanbevolen.<br><br><a href='http://www.m-gb.org/index.php?id=download_gb' class='admin' target='_blank' title='Update now'>To the new version</a>";
	$lang['same_version'] = "U gebruikt de nieuwste versie.<br>Een update is niet nodig.";
	$lang['newer_version'] = "Uw versie is nieuwer dan de nieuwste stabiele versie.<br>Een update is niet nodig.";
	$lang['new_version_available'] = "Een nieuwe versie is beschikbaar: <a href='http://www.m-gb.org/files/latest/mgb-latest.zip' class='admin' target='_blank' title='Upgrade now!'>{LATEST_VERSION}</a>";

	// lostpassword.php
	$lang['lostpassword_mail'] = "Uw e-mail adres:";
	$lang['get_new_pw'] = "Aanvraag nieuw wachtwoord";
	$lang['lostpassword_success'] = "De aanvraag wordt verwerkt. Zodadelijk ontvangt u een e-mail<br>met een bevestigings-link. Klik hierop om uw nieuw wachtwoord te bevestigen.";
	$lang['lostpassword_no_success'] = "Jou verzoek kan niet afgehandeld worden, er is een probleem met de mailserver.";
	$lang['lostpassword_success_created'] = "Uw nieuwe login details zijn<br>naar u gestuurd per e-mail.";
	$lang['lostpassword_no_success_created'] = "Jou verzoek kan niet afgehandeld worden, er is een probleem met de mailserver.";
?>
